@@ -2,7 +2,6 @@ import typing
 
 __all__ = (
     "PydbmBaseException",
-    "DoesNotExists",
     "PydbmTypeError",
     "ValidationError",
 )
@@ -14,12 +13,6 @@ class PydbmBaseException(Exception):
     pass
 
 
-class DoesNotExists(PydbmBaseException):
-    """Exception for not found id in the models."""
-
-    pass
-
-
 class PydbmTypeError(PydbmBaseException, TypeError):
     """Exception for not valid type of value."""
 
@@ -35,4 +28,4 @@ class ValidationError(PydbmBaseException):
         self.error = error
 
     def __str__(self) -> str:
-        return f"Invalid value for {self.field_name}={self.field_value!r}; {self.error}."  # noqa: E501
+        return f"Invalid value for {self.field_name}={self.field_value!r}; {self.error}."
